@@ -88,6 +88,7 @@ MAP_PROTOCOLS = {
     "DNS-over-HTTPS": "doh_queries",
     "DNS-over-QUIC": "doq_queries",
     "DNS-over-TLS": "dot_queries",
+    "TCP": "tcp_queries",
     "UDP": "udp_queries",
 }
 MAP_STATUS = {
@@ -97,7 +98,7 @@ MAP_STATUS = {
     "relayed": "relayed_queries",
 }
 
-MAP_SETTING = {
+MAP_SETTING = {  # pylint: disable=consider-using-namedtuple-or-dataclass
     ATTR_BLOCK_PAGE: {
         ATTR_URL: ENDPOINTS[ATTR_BLOCK_PAGE],
         ATTR_NAME: ATTR_ENABLED,
